@@ -1,5 +1,5 @@
 # ------------------------------------------------------------------------------
-#  Copyleft 2015-2020  PacMiam
+#  Copyleft 2015-2021  PacMiam
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -44,7 +44,6 @@ import logging
 from logging.config import fileConfig
 
 # System
-from fcntl import flock, LOCK_EX, LOCK_NB
 from os import getpid
 from os import name as os_name
 from sys import exit as sys_exit
@@ -57,7 +56,7 @@ from sys import exit as sys_exit
 class GEM(object):
 
     Instance = "gem"
-    Version = "0.10.4"
+    Version = "0.11.0"
 
     Log = "gem.log"
     Logger = "log.conf"
@@ -211,8 +210,15 @@ class GEM(object):
         with self.__lock_path.open('wb') as pipe:
             # Register current PID into file
             pipe.write(bytes(f"{self.__pid} {timestamp}", "UTF-8"))
-            # Perform the lock operation on file
-            flock(pipe, LOCK_EX | LOCK_NB)
+
+            try:
+                from fcntl import flock, LOCK_EX, LOCK_NB
+
+                # Perform the lock operation on file
+                flock(pipe, LOCK_EX | LOCK_NB)
+
+            except ImportError:
+                pass
 
         return False
 
@@ -306,16 +312,12 @@ class GEM(object):
         # Check GEM configuration files
         for filename in (GEM.Consoles, GEM.Emulators):
             path = Path(self.get_config(filename))
+            if path.exists():
+                self.logger.debug(f"Read {path} configuration file")
 
-            # Configuration file not exists
-            if not path.exists():
-                raise FileNotFoundError(f"Cannot found {path} file")
-
-            self.logger.debug(f"Read {path} configuration file")
-
-            # Store Configuration object
-            self.__configurations[path.stem] = Configuration(path,
-                                                             strict=False)
+                # Store Configuration object
+                self.__configurations[path.stem] = \
+                    Configuration(path, strict=False)
 
         path = Path(self.get_config(GEM.Environment))
 
@@ -334,11 +336,12 @@ class GEM(object):
 
         emulators = self.__configurations["emulators"]
 
-        for section in emulators.sections():
-            self.add_emulator(section, emulators.items(section))
+        if emulators is not None:
+            for section in emulators.sections():
+                self.add_emulator(section, emulators.items(section))
 
-        self.logger.debug(
-            f"{len(self.emulators)} emulator(s) has been founded")
+            self.logger.debug(
+                f"{len(self.emulators)} emulator(s) has been founded")
 
     def __init_consoles(self):
         """ Initalize consoles
@@ -351,11 +354,12 @@ class GEM(object):
 
         consoles = self.__configurations["consoles"]
 
-        for section in consoles.sections():
-            self.add_console(section, consoles.items(section))
+        if consoles is not None:
+            for section in consoles.sections():
+                self.add_console(section, consoles.items(section))
 
-        self.logger.debug(
-            f"{len(self.consoles)} console(s) has been founded")
+            self.logger.debug(
+                f"{len(self.consoles)} console(s) has been founded")
 
     def init(self):
         """ Initalize data from configuration files
@@ -375,13 +379,8 @@ class GEM(object):
         # Load user consoles
         self.__init_consoles()
 
-    def check_database(self, updater=None):
+    def check_database(self):
         """ Check database and migrate to lastest GEM version if needed
-
-        Parameters
-        ----------
-        updater : class, optionnal
-            Class to call when database is modified
         """
 
         if self.__need_migration:
@@ -429,11 +428,7 @@ class GEM(object):
                     # Get new table columns
                     new_columns_name = new_database.get_columns("games")
 
-                    if updater is not None:
-                        updater.init(len(games))
-
-                    counter = int()
-                    for row in games:
+                    for counter, row in enumerate(games):
                         counter += 1
 
                         row_data = dict()
@@ -447,8 +442,7 @@ class GEM(object):
 
                         new_database.insert("games", row_data)
 
-                        if updater is not None:
-                            updater.update(counter)
+                        yield counter, len(games)
 
                 # ----------------------------------------
                 #   Remove backup
@@ -473,8 +467,7 @@ class GEM(object):
             # Remove backup
             self.__backup_path.unlink()
 
-        if updater is not None:
-            updater.close()
+        yield None
 
     def write_object(self, data):
         """ Write data into a specific configuration file
@@ -562,7 +555,7 @@ class GEM(object):
                     structure = self.__data[name][element].as_dict()
 
                     for key, value in sorted(structure.items()):
-                        if value is None:
+                        if value is None or value == "None":
                             value = str()
 
                         if type(value) is bool:
