@@ -1,5 +1,5 @@
 # ------------------------------------------------------------------------------
-#  Copyleft 2015-2020  PacMiam
+#  Copyleft 2015-2021  PacMiam
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -32,15 +32,8 @@ from geode_gem.ui.widgets.window import CommonWindow
 from geode_gem.ui.widgets.widgets import ListBoxItem
 
 # GObject
-try:
-    from gi import require_version
-    require_version("Gtk", "3.0")
-
-    from gi.repository import Gtk, GLib, Gdk, Pango
-
-except ImportError as error:
-    from sys import exit
-    exit("Cannot found python3-gobject module: %s" % str(error))
+from gi import require_version
+from gi.repository import Gdk, GLib, Gtk, Pango
 
 # Translation
 from gettext import gettext as _
@@ -266,17 +259,17 @@ class EditorDialog(CommonWindow):
                 self.buffer_editor.set_language(
                     self.language_editor.guess_language(str(self.path)))
 
-                if self.parent is not None:
+                if self.main_parent is not None:
                     self.text_editor.set_tab_width(
-                        self.parent.config.getint(
+                        self.main_parent.config.getint(
                             "editor", "tab", fallback=4))
                     self.text_editor.set_show_line_numbers(
-                        self.parent.config.getboolean(
+                        self.main_parent.config.getboolean(
                             "editor", "lines", fallback=False))
 
                     self.buffer_editor.set_style_scheme(
                         self.style_editor.get_scheme(
-                            self.parent.config.item(
+                            self.main_parent.config.item(
                                 "editor", "colorscheme", "classic")))
 
             except Exception:
@@ -413,7 +406,8 @@ class EditorDialog(CommonWindow):
 
         # Parsing font from configuration file
         try:
-            font = self.parent.config.item("editor", "font", "Sans 12").split()
+            font = self.main_parent.config.item(
+                "editor", "font", "Sans 12").split()
 
             # Retrieve informations based on pattern '<family font> <size>'
             font_size = int(font[-1])
