@@ -1,5 +1,5 @@
 # ------------------------------------------------------------------------------
-#  Copyleft 2015-2020  PacMiam
+#  Copyleft 2015-2021  PacMiam
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -22,15 +22,7 @@ from geode_gem.ui.data import Icons
 from geode_gem.ui.widgets.window import CommonWindow
 
 # GObject
-try:
-    from gi import require_version
-    require_version("Gtk", "3.0")
-
-    from gi.repository import Gtk, Gdk, GdkPixbuf, GLib
-
-except ImportError as error:
-    from sys import exit
-    exit("Cannot found python3-gobject module: %s" % str(error))
+from gi.repository import Gdk, GdkPixbuf, GLib, Gtk
 
 
 # ------------------------------------------------------------------------------
