@@ -1,5 +1,5 @@
 # ------------------------------------------------------------------------------
-#  Copyleft 2015-2020  PacMiam
+#  Copyleft 2015-2021  PacMiam
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -29,15 +29,7 @@ from geode_gem.ui.dialog.icons import IconsDialog
 from geode_gem.ui.widgets.window import CommonWindow
 
 # GObject
-try:
-    from gi import require_version
-    require_version("Gtk", "3.0")
-
-    from gi.repository import Gtk, GdkPixbuf, Pango
-
-except ImportError as error:
-    from sys import exit
-    exit("Cannot found python3-gobject module: %s" % str(error))
+from gi.repository import GdkPixbuf, Gtk, Pango
 
 # Translation
 from gettext import gettext as _
@@ -91,15 +83,6 @@ class ConsolePreferences(CommonWindow):
         self.file_error = False
         self.emulator_error = False
 
-        if getattr(parent, "interface", None) is not None:
-            self.interface = parent.interface
-
-        else:
-            self.interface = parent
-
-        # Empty Pixbuf icon
-        self.icons = parent.icons
-
         self.help_data = {
             "order": [
                 "Description",
@@ -201,7 +184,7 @@ class ConsolePreferences(CommonWindow):
         self.label_name.set_halign(Gtk.Align.END)
         self.label_name.set_valign(Gtk.Align.CENTER)
         self.label_name.set_justify(Gtk.Justification.RIGHT)
-        self.label_name.get_style_context().add_class("dim-label")
+        self.label_name.get_style_context().add_class(Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_name.set_text(_("Name"))
 
         self.entry_name.set_hexpand(True)
@@ -211,7 +194,7 @@ class ConsolePreferences(CommonWindow):
         self.label_icon.set_halign(Gtk.Align.END)
         self.label_icon.set_valign(Gtk.Align.CENTER)
         self.label_icon.set_justify(Gtk.Justification.RIGHT)
-        self.label_icon.get_style_context().add_class("dim-label")
+        self.label_icon.get_style_context().add_class(Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_icon.set_text(_("Icon"))
 
         self.entry_icon.set_hexpand(True)
@@ -221,7 +204,8 @@ class ConsolePreferences(CommonWindow):
         self.label_folder.set_halign(Gtk.Align.END)
         self.label_folder.set_valign(Gtk.Align.CENTER)
         self.label_folder.set_justify(Gtk.Justification.RIGHT)
-        self.label_folder.get_style_context().add_class("dim-label")
+        self.label_folder.get_style_context().add_class(
+            Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_folder.set_text(_("Games folder"))
 
         self.file_folder.set_action(Gtk.FileChooserAction.SELECT_FOLDER)
@@ -234,7 +218,8 @@ class ConsolePreferences(CommonWindow):
         self.label_favorite.set_label(_("Favorite"))
         self.label_favorite.set_halign(Gtk.Align.END)
         self.label_favorite.set_valign(Gtk.Align.CENTER)
-        self.label_favorite.get_style_context().add_class("dim-label")
+        self.label_favorite.get_style_context().add_class(
+            Gtk.STYLE_CLASS_DIM_LABEL)
 
         self.switch_favorite.set_margin_top(12)
         self.switch_favorite.set_halign(Gtk.Align.START)
@@ -244,7 +229,8 @@ class ConsolePreferences(CommonWindow):
         self.label_recursive.set_label(_("Recursive"))
         self.label_recursive.set_halign(Gtk.Align.END)
         self.label_recursive.set_valign(Gtk.Align.CENTER)
-        self.label_recursive.get_style_context().add_class("dim-label")
+        self.label_recursive.get_style_context().add_class(
+            Gtk.STYLE_CLASS_DIM_LABEL)
 
         self.switch_recursive.set_margin_top(12)
         self.switch_recursive.set_no_show_all(True)
@@ -277,7 +263,8 @@ class ConsolePreferences(CommonWindow):
         self.label_default.set_halign(Gtk.Align.END)
         self.label_default.set_valign(Gtk.Align.CENTER)
         self.label_default.set_justify(Gtk.Justification.RIGHT)
-        self.label_default.get_style_context().add_class("dim-label")
+        self.label_default.get_style_context().add_class(
+            Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_default.set_text(_("Emulator"))
 
         self.model_emulators.set_sort_column_id(1, Gtk.SortType.ASCENDING)
@@ -295,7 +282,8 @@ class ConsolePreferences(CommonWindow):
         self.label_extensions.set_halign(Gtk.Align.END)
         self.label_extensions.set_valign(Gtk.Align.CENTER)
         self.label_extensions.set_justify(Gtk.Justification.RIGHT)
-        self.label_extensions.get_style_context().add_class("dim-label")
+        self.label_extensions.get_style_context().add_class(
+            Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_extensions.set_text(_("Extensions"))
 
         self.entry_extensions.set_hexpand(True)
@@ -473,7 +461,7 @@ class ConsolePreferences(CommonWindow):
 
             if emulator.exists:
 
-                icon = self.interface.get_pixbuf_from_cache(
+                icon = self.main_parent.get_pixbuf_from_cache(
                     "emulators",
                     22,
                     emulator.id,
@@ -481,7 +469,7 @@ class ConsolePreferences(CommonWindow):
                     use_cache=False)
 
                 if icon is None:
-                    icon = self.icons.blank(22)
+                    icon = self.main_parent.icons_blank.get(22)
 
                 emulators_rows[emulator.id] = self.model_emulators.append(
                     [icon, emulator.name, emulator.id])
@@ -515,11 +503,11 @@ class ConsolePreferences(CommonWindow):
             if self.path is not None:
                 self.entry_icon.set_text(str(self.path))
 
-                icon = self.interface.get_pixbuf_from_cache(
+                icon = self.main_parent.get_pixbuf_from_cache(
                     "consoles", 64, self.console.id, self.console.icon)
 
                 if icon is None:
-                    icon = self.icons.blank(64)
+                    icon = self.main_parent.icons_blank.get(64)
 
                 self.image_console.set_from_pixbuf(icon)
 
@@ -781,7 +769,7 @@ class ConsolePreferences(CommonWindow):
         """
 
         # Retrieve an empty icon
-        icon = self.icons.blank(size)
+        icon = self.main_parent.icons_blank.get(size)
 
         if path is not None:
 
