@@ -1,5 +1,5 @@
 # ------------------------------------------------------------------------------
-#  Copyleft 2015-2020  PacMiam
+#  Copyleft 2015-2021  PacMiam
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -21,22 +21,7 @@
 from geode_gem.ui.data import Icons
 
 # GObject
-try:
-    from gi import require_version
-
-    require_version("Gtk", "3.0")
-
-    from gi.repository import Gtk
-    from gi.repository import Gdk
-    from gi.repository import Pango
-
-except ImportError as error:
-    from sys import exit
-
-    exit("Cannot found python3-gobject module: %s" % str(error))
-
-# Logging
-from logging import getLogger
+from gi.repository import Gdk, Gtk, Pango
 
 # Translation
 from gettext import gettext as _
@@ -78,7 +63,10 @@ class CommonWindow(object):
         self.help_data = list()
         self.sensitive_data = dict()
 
-        self.logger = getLogger("gem")
+        # Ensure to retrieve the root parent
+        self.main_parent = getattr(parent, "main_parent", parent)
+        # Retrieve logging instance from root parent
+        self.logger = self.main_parent.logger
 
         # ------------------------------------
         #   Prepare interface
@@ -94,53 +82,29 @@ class CommonWindow(object):
         """ Initialize interface widgets
         """
 
-        # Gtk.Window
-        if self.parent is None:
-            self.window = Gtk.Window()
-
-        # Gtk.Dialog
-        else:
-            self.window = Gtk.Dialog(use_header_bar=not self.use_classic_theme)
-
-            if hasattr(self.parent, "window"):
-                self.window.set_transient_for(self.parent.window)
-
-            else:
-                self.window.set_transient_for(self.parent)
-
-            self.window.set_modal(True)
-            self.window.set_destroy_with_parent(True)
+        self.window = Gtk.Dialog(use_header_bar=not self.use_classic_theme)
 
         # Properties
-        self.window.set_title(self.title)
-        self.window.set_default_icon_name(self.icon)
-        self.window.set_can_focus(True)
-        self.window.set_resizable(False)
-        self.window.set_keep_above(True)
-
-        self.window.set_type_hint(Gdk.WindowTypeHint.DIALOG)
-
-        self.window.set_position(Gtk.WindowPosition.CENTER)
-
         self.window.set_border_width(0)
+        self.window.set_can_focus(True)
+        self.window.set_default_icon_name(self.icon)
+        self.window.set_destroy_with_parent(True)
+        self.window.set_keep_above(True)
+        self.window.set_modal(True)
+        self.window.set_position(Gtk.WindowPosition.CENTER)
+        self.window.set_resizable(False)
+        self.window.set_title(self.title)
+        self.window.set_transient_for(self.main_parent)
+        self.window.set_type_hint(Gdk.WindowTypeHint.DIALOG)
 
         # ------------------------------------
         #   Grid
         # ------------------------------------
 
-        # Gtk.Window
-        if self.parent is None:
-            self.grid = Gtk.Box()
+        self.grid = self.window.get_content_area()
 
-            # Properties
-            self.grid.set_orientation(Gtk.Orientation.VERTICAL)
-
-        # Gtk.Dialog
-        else:
-            self.grid = self.window.get_content_area()
-
-            # Remove the old action grid
-            self.grid.remove(self.grid.get_children()[0])
+        # Remove the old action grid
+        self.grid.remove(self.grid.get_children()[0])
 
         self.grid_tools = Gtk.Box()
         self.grid_actions = Gtk.Box()
@@ -160,18 +124,7 @@ class CommonWindow(object):
 
         if not self.use_classic_theme:
 
-            # Gtk.Window
-            if self.parent is None:
-                self.headerbar = Gtk.HeaderBar()
-
-                # Properties
-                self.headerbar.set_title(self.title)
-
-                self.window.set_titlebar(self.headerbar)
-
-            # Gtk.Dialog
-            else:
-                self.headerbar = self.window.get_header_bar()
+            self.headerbar = self.window.get_header_bar()
 
             self.headerbar_image = Gtk.Image()
 
@@ -285,24 +238,13 @@ class CommonWindow(object):
 
         self.show_all()
 
-        # Gtk.Dialog
-        if self.parent is not None:
-            return self.window.run()
-
-        # Gtk.Window
-        Gtk.main()
+        return self.window.run()
 
     def destroy(self, *args):
         """ Destroy dialog
         """
 
-        # Gtk.Window
-        if self.parent is None:
-            Gtk.main_quit()
-
-        # Gtk.Dialog
-        else:
-            self.window.destroy()
+        self.window.destroy()
 
     def add_widget(self, widget, align=Gtk.Align.START,
                    expand=False, fill=False, padding=int()):
@@ -408,9 +350,11 @@ class CommonWindow(object):
 
         # Add a style to button for specific responses
         if response in [Gtk.ResponseType.APPLY, Gtk.ResponseType.ACCEPT]:
-            button.get_style_context().add_class("suggested-action")
+            button.get_style_context().add_class(
+                Gtk.STYLE_CLASS_SUGGESTED_ACTION)
         elif response in [Gtk.ResponseType.YES, Gtk.ResponseType.REJECT]:
-            button.get_style_context().add_class("destructive-action")
+            button.get_style_context().add_class(
+                Gtk.STYLE_CLASS_DESTRUCTIVE_ACTION)
 
         if align == Gtk.Align.END:
             self.grid_actions_buttons.pack_end(button, False, False, 0)
